******** Beginning of example2.do **********************************************
/*
  Demonstrate the use of -tempfile- and -dsconcat-
  with resultssets from -descsave- and -xcollapse-.
  Unofficial Stata packages required:
  -descsave-, -xcollapse-. -dsconcat-.
*/

version 8.0

sysuse auto, clear

tempfile tf0 tf1 tf2 tf3 tf4 tf5 tf6 tf7 tf8 tf9

/*
  Create resultsset with 1 obs per variable using -descsave-
*/

descsave price mpg headroom trunk weight length turn displacement gear_ratio, ///
  saving(`tf0', replace) gsort(name) keep(order name varlab)
more

/*
  Create 1 resultsset per variable using -xcollapse-
*/

xcollapse (median) median=price, idstr(price) by(foreign) ///
  saving(`tf1', replace)
more
xcollapse (median) median=mpg, idstr(mpg) by(foreign) ///
  saving(`tf2', replace)
more
xcollapse (median) median=headroom, idstr(headroom) by(foreign) ///
  saving(`tf3', replace)
more
xcollapse (median) median=trunk, idstr(trunk) by(foreign) ///
  saving(`tf4', replace)
more
xcollapse (median) median=weight, idstr(weight) by(foreign) ///
  saving(`tf5', replace)
more
xcollapse (median) median=length, idstr(length) by(foreign) ///
  saving(`tf6', replace)
more
xcollapse (median) median=turn, idstr(turn) by(foreign) ///
  saving(`tf7', replace)
more
xcollapse (median) median=displacement, idstr(displacement) by(foreign) ///
  saving(`tf8', replace)
more
xcollapse (median) median=gear_ratio, idstr(gear_ratio) by(foreign) ///
  saving(`tf9', replace)
more

/*
  Concatenate -xcollapse- resultssets
*/

dsconcat `tf1' `tf2' `tf3' `tf4' `tf5' `tf6' `tf7' `tf8' `tf9'
lab var median "Median"
format median %9.0g
describe
more
list, sepby(idstr)
more

/*
  Merge in -descsave- resultsset
*/

rename idstr name
lab var name "Variable name"
lab var median "Median"
sort name
merge name using `tf0'
drop _merge
sort foreign order
describe
more
by foreign: list order name varlab median, noobs
more

exit
******** End of example2.do ****************************************************
