******** Beginning of example4.do **********************************************
/*
  Demonstrate the use of -descsave-, -factext- and -factmerg-
  to create plots and tables from a -parmby- resultsset with the -label- option.
  Unofficial Stata packages required:
  -descsave-, -parmest-, -factext-, -factmerg-, -sencode-, -eclplot-.
*/

version 8.0

set scheme s1mono

sysuse auto, clear

/*
  Define baseline reference categories for -foreign- and -rep78-
*/

char foreign[omit] 0
char rep78[omit] 3
describe
char list
more

/*
  Create and list a do-file to reconstruct -foreign- and -rep78-
*/

tempfile tf0
descsave foreign rep78, dofile(`tf0', replace) char(omit)
more
type `tf0'
more

/*
  Create a -parmby- resultsset of regression parameters
*/

parmby  "xi: regress mpg i.foreign i.rep78, robust", ///
  label norestore format(estimate min95 max95 %8.2f p %-8.2g)
more
describe
more
list parm label estimate min95 max95 p, noobs clean
more

/*
  Extract factors from string variable -label-
*/

factext, dofile(`tf0')
describe
more
list parm label foreign rep78 estimate min95 max95, noobs clean
more

/*
  Plot single-factor confidence interval plot
*/

eclplot estimate min95 max95 rep78, horizontal ///
  xline(0, lpattern(shortdash)) ///
  xtitle("Difference (miles per gallon)") ///
  yscale(range(0 6)) ylabel(1(1)5) ///
  estopts(mcolor(black) msize(large)) ///
  ciopts(msize(huge) blcolor(black))  
* To save Figure 3 to disk, insert the line:
* graph save figure3, replace
more

/*
  Generate factor label and value variables
*/

factmerg foreign rep78, flabel(faclab) fvalue(facval)
describe
more
list parm label faclab facval estimate min95 max95, noobs clean
more

/*
  Generate row label variable -cargp-
*/

generate cargp=faclab+": "+facval if !missing(faclab)
sencode cargp, replace
lab var cargp "Car group"
describe
more
list parm label cargp estimate min95 max95, noobs clean
more

/*
  Plot multi-factor confidence interval plot
*/

eclplot estimate min95 max95 cargp, horizontal ///
  xline(0, lpattern(shortdash)) ///
  xtitle("Difference (miles per gallon)") ///
  yscale(range(0 6)) ylabel(1(1)5, notick) ///
  estopts(mcolor(black) msize(large)) ///
  ciopts(msize(huge) blcolor(black))
* To save Figure 4 to disk, insert the line:
* graph save figure4, replace
more

exit
******** End of example4.do ****************************************************
